#!/bin/bash

Authorized="/home/secuser/.ssh/authorized_keys"
Custom_Key="custom_key"

sc_pkey="-----BEGIN RSA PRIVATE KEY-----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-----END RSA PRIVATE KEY-----"

echo "$sc_pkey" > /home/secuser/.ssh/otu_id_rsa_4096
chown secuser:secuser /home/secuser/.ssh/otu_id_rsa_4096
chmod 600 /home/secuser/.ssh/otu_id_rsa_4096

# remove old custom_key.pub in /home/secuser/.ssh/authorized_keys
sed -i '/custom_key.pub/d' $Authorized

# add common pub key in /home/secuser/.ssh/authorized_keys
echo "">> $Authorized
echo "ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAACAQDhVAlSVzkefsoC6uoCgPTdbF4NKKvd7rSCwgDh5fdwMb+9ZK5BKC4+AqhuGUE31iFV5GVZkjpTcWv7Em9lkElV7ktt8ZjjaN1tES+difw7yskWQQXzBZYkN79t9S1ttROq+aNEwH02CpesZBzjw6fpi9qJK6egrLKGHnlUABD/I89MmirP+JpuHh54PtqIdlipvWg9hn8FTPBGauvDuBLEKjNdOIKovqZ0wtieM7g3lpm827EzxNmYkU/ekG9koPsBsR4/GwA0AxiEK1XUHjuE7eg3XiQGYUxz7dGb1CuTSZhtrIGdaE+r7oVAlJM7aCQDQ9Tn6t/Eaysui9SYygMwKsngjqtus1F5mm1NDlNDrDa4PWoCwp8RyameHnxDvJc9lgjyKERiqu6MCrORnfACJwtbKbZrlC06HeBQxPXRzpaYzP54f7e7tL6u9Sof4gFiLbl19Al3Mt517OXUiMGBUW+gGp28AxXgmqEe2dAlsJ2EZQcK5vPlvh0bPHgMZyDttGwe8NX9Pd92TMcwnpBxWBSZiOCqRh7+ER7YPkHPUA5rz5/mr1e0qK6sdsCqU4SGdYVn75/X/BNo0hGuHfiB623NTuJl91IjhYXVzgyvrv2A0wkzZZuXtetGqIL6UTkxHnVyBQVCNWZs4JV3OsqnkFZhfVnkcKRGXoBHoYcz9w== pubkey" >> $Authorized

echo "">> $Authorized

# suppression des doublons et des lignes vides
D=$( date +%s )
grep . $Authorized | sort -u > /tmp/Authorized-$D
mv /tmp/Authorized-$D $Authorized
chmod 600 $Authorized

#force secuser ownership
chown secuser:secuser /home/secuser/.ssh/authorized_keys

rm -rf /home/secuser/.ssh/$Custom_Key*

